Zadane.pl - Uczymy się w grupie

# Zarejestruj się, by zacząć dzielić się wiedzą

Zarejestruj się przez Facebook
albo

- pokaż
- dziewczyna
  chłopak

# Regulamin serwisu internetowego Zadane.pl

## Postanowienia ogólne

### § 1

Regulamin określa zasady działania serwisu Zadane.pl (zwanego dalej Serwisem), w tym zasady świadczenia przez Serwis usług drogą elektroniczną.

Użytkownik obowiązany jest do zapoznania się z treścią niniejszego Regulaminu.

Od Użytkowników oczekuje się uczciwości i respektowania postanowień Regulaminu.

## Definicje

### § 2

Regulamin – niniejszy regulamin, określający zasady działania Serwisu, w tym zasady świadczenia przez Serwis usług drogą elektroniczną.

Serwis – serwis Zadane.pl prowadzony przez Zadane.pl sp. z o.o., stanowiący system informatyczny wraz z całą zawartością i funkcjonalnością obsługiwanej przez niego strony internetowej, umożliwiający Użytkownikom korzystanie z usług wskazanych w Regulaminie; ilekroć w Regulaminie mowa o Serwisie, należy przez to rozumieć także Organizatora;

Organizator – organizator Serwisu – Zadane.pl sp. z o.o., Marszałkowska 84/92 lokal 117, 00-514 Warszawa

Administrator – organizator Serwisu lub osoba przez niego upoważniona do pełnego lub ograniczonego zarządzania Serwisem.

Użytkownik – korzystająca z Serwisu pełnoletnia lub (za zgodą przedstawicieli ustawowych) niepełnoletnia osoba fizyczna, osoba prawna lub jednostka organizacyjna nieposiadająca osobowości prawnej.

Treść – wszelkie treści umieszczane przez Użytkownika w Serwisie, będące utworami w rozumieniu ustawy o prawie autorskim i prawach pokrewnych lub informacjami niechronionymi prawem autorskim,

Konto – indywidualne, elektroniczne konto w ramach Serwisu aktywowane dla Użytkownika w celu umożliwienia mu korzystania z usług Serwisu.

## Usługi Serwisu

### § 3

W ramach Serwisu Użytkownikom udostępniany jest system informatyczny w celu umieszczania przez Użytkowników Treści oraz ich przechowywania w Serwisie.

Korzystanie z serwisu, za wyjątkiem przeglądania umieszczonych w nim Treści i reklam wymaga rejestracji, której Użytkownicy dokonują na zasadach wskazanych w Regulaminie oraz uwzględnienia określonych w Regulaminie zasad umieszczania i przechowywania Treści.

W ramach Serwisu Użytkownicy zarejestrowani w Serwisie mogą – w drodze wypełnienie stosownych formularzy elektronicznych - umieszczać i przechowywać następujące Treści:

- pytania z zakresu wybranego przedmiotu szkolnego,
- udzielenie odpowiedzi na ww. pytania,
- wypracowania lub prace tematyczne z zakresu dowolnego przedmiotu szkolnego,
- prywatne wiadomości - w ramach komunikowania się Użytkowników,
- wypowiedzi Użytkowników - w ramach grup dyskusyjnych i komentarzy w profilach,
- zapytania i wyjaśnienia do udzielonych odpowiedzi – w ramach dyskusji dotyczącej odpowiedzi,

W ramach korzystania z usług Serwisu Użytkownik może zdobywać punkty. Zasady zdobywania punktów oraz zasady ich użytkownika w Serwisie określa załącznik do Regulaminu (-> Punkty).

### Pytania oczekujące na odpowiedź

Umieszczenie w Serwisie pytania z zakresu wybranego przedmiotu szkolnego mają na celu uzyskanie odpowiedzi od innego Użytkownika.

Zagadnienia objęte pytaniem muszą być sformułowane w sposób konkretny, rzeczowy oraz wyczerpujący, w szczególności nie mogą zawierać odwołań do innych źródeł, bez zapoznania się, z którymi zagadnienia te nie są zrozumiałe.

Użytkownicy przyjmują do wiadomości, że pytania zawierające większą ilość zagadnień wymagających rozwiązania powinny zostać podzielone na dwa lub większą ilość pytań i w tej formie uwidocznione pozostałym Użytkownikom. Moderatorzy w takiej sytuacji mogą usunąć pytanie i poprosić o utworzenie kilku pytań.

Umieszczenie pytań oczekujących na odpowiedź może mieć charakter odpłatny lub nieodpłatny – z uwzględnieniem następujących założeń. Umieszczając pytanie w Serwisie, Użytkownik ma możliwość skorzystania z jednej z następujących opcji formatu wyświetlania jego pytania na ogólnodostępnej w Serwisie liście pytań oczekujących na odpowiedź:

- Opcja bezpłatna – Standardowa – w przypadku skorzystania z niej przez Użytkownika pytanie zostaje umieszczone na pierwszym miejscu, pod pytaniami ulepszonymi i pytaniami premium,
- Opcja płatna – tzw. Pytanie ulepszone – pytanie zostaje umieszczone na liście pytań czekających na odpowiedź w ten sposób, że jest wyróżnione kolorystycznie spośród innych pytań znajdujących się na liście oraz zostaje wyświetlone x kolejnym osobom odwiedzającym tę listę, jako znajdujące się na pierwszych jej miejscach,
- Opcja płatna – tzw. Pytanie Premium - pytanie zostaje umieszczone na liście pytań oczekujących na odpowiedź w ten sposób, że jest wyróżnione kolorystycznie oraz zostaje wyświetlone na pierwszych miejscach tej listy x osobom posiadającym najwyższe rangi w Serwisie – z uwzględnieniem rozumienia pojęcia „rangi" określonego w załączniku do Regulaminu

Należność z tytułu umieszczenia i przechowania w Serwisie pytań, regulowana jest w wysokości określonej w Cenniku (link), na zasadach określonych w Regulaminie.

Użytkownik przyjmuje do wiadomości, że w przypadku zaprzestania korzystania z usług Serwisu umieszczone przez niego w Serwisie pytanie może być przechowywane przez Administratora bezterminowo.

### Udzielanie odpowiedzi na pytania

Umieszczona w Serwisie odpowiedź powinna obejmować rozstrzygnięcie wszystkich zagadnień objętych pytaniem.

Odpowiedź na pytanie nie może polegać na umieszczeniu w Serwisie linku do innego serwisu internetowego ani stanowić kopii odpowiedzi umieszczonej wcześniej w Serwisie przez innego Użytkownika.

Udzielenie odpowiedzi na pytanie z zakresu przedmiotu ścisłego, które wymaga przeprowadzenia stosownych obliczeń, nie może polegać na podaniu jedynie ich wyniku końcowego, lecz musi również obejmować ww. obliczenia. Odpowiedź powinna być wytłumaczeniem danego problemu, jaki przedstawił użytkownik, by mógł on zrozumieć jak należy taki problem rozwiązać.

Użytkownik będący autorem odpowiedzi z tytułu jego udostępnienia w Serwisie otrzymuje punkty – w ilości oraz na zasadach określonych w Regulaminie.

Umieszczona przez Użytkownika odpowiedź może zostać usunięta z Serwisu w przypadku konieczności usunięcia pytania, którego ta odpowiedź dotyczy.

W przypadku dodania pytania które jest niezgodne z regulaminem, zostanie ono usunięte, a punkty zdobyte za odpowiedź zostaną odebrane odpowiadającym.

## Dyskusja

Użytkownicy Serwisu, w ramach dyskusji pod pytaniem, mogą toczyć debatę odnoszącą się do danego pytania.

### Wypracowania oraz prace tematyczne

Wypracowania oraz prace tematyczne mogą dotyczyć zagadnień z zakresu dowolnie wybranego przedmiotu szkolnego.

Umieszczone w Serwisie wypracowania oraz prace tematyczne zostają uwidocznione w zasobach Serwisu dla innych Użytkowników po weryfikacji ich treści przez moderatora ze strony Serwisu. W przypadku stwierdzenia przez moderatora, że umieszczone przez Użytkownika Treści stanowią spam, ich poziom merytoryczny jest bardzo niski lub są one objętościowo nazbyt krótkie, Treści te mogą zostać usunięte z zasobów Serwisu.

Użytkownik będący autorem wypracowania oraz pracy tematycznej z tytułu ich udostępnienia w Serwisie otrzymuje punkty – w ilości oraz na zasadach określonych w Regulaminie.

### Prywatne wiadomości

W ramach Serwisu Użytkownicy mogą przekazywać między sobą prywatne wiadomości, korzystając z komunikatora udostępnionego na ten cel w Serwisie.

### Wypowiedzi w ramach grup dyskusyjnych. Grupy dyskusyjne.

Użytkownicy mogą uczestniczyć w Serwisie w grupach dyskusyjnych, wypowiadając się na wybrane tematy.

Użytkownik może przyłączyć się do istniejących grup dyskusyjnych lub utworzyć własną grupę (grupy) dyskusyjną.

Organizator Serwisu nie jest organizatorem ani uczestnikiem grup dyskusyjnych. Inicjatywa oraz aktywność w tym zakresie leży wyłącznie po stronie Użytkowników.

Grupy dyskusyjne mogą mieć charakter otwarty lub zamknięty.

Otwarta grupa dyskusyjna – to grupa dyskusyjna, do której każdy Użytkownik może bez ograniczeń dołączyć, zapoznawać się z wypowiedziami jej uczestników oraz umieszczać w niej własne wypowiedzi.

Zamknięta grupa dyskusyjna – do grupa dyskusyjna, do której Użytkownik może dołączyć na swoją prośbę, za zgodą założyciela danej grupy lub na jego zaproszenie, zapoznawać się z wypowiedziami jej uczestników oraz umieszczać w niej własne wypowiedzi.

Członkostwo w grupach dyskusyjnych opiera się na zasadzie dobrowolności. Użytkownik może zrezygnować z udziału w nich w każdym czasie.

Założycielowi grupy dyskusyjnej przysługują następujące uprawnienia:

- prawo usuwania postów oraz tematów zamieszczanych na forum swojej grupy dyskusyjnej,
- prawo powoływania i odwoływania moderatorów w swojej grupie dyskusyjnej,
- prawo wysyłania zaproszeń do uczestnictwa w swojej grupie dyskusyjnej do wybranych Użytkowników oraz prawo akceptacji i odrzucenia wniosków Użytkowników o umożliwienie im udziału w tej grupie,
- prawo wysyłania masowej prywatnej wiadomości do członków swojej grupy dyskusyjnej,
- prawo usuwania Użytkownika z założonej przez Założyciela grupy dyskusyjnej oraz blokowania dostępu do niej Użytkownikom nie należącym do tej grupy.

Moderatorzy mają prawo do usunięcia grupy w przypadku braku aktywności, bądź naruszenia regulaminu serwisu oraz prawa powszechnie obowiązującego

## Komentarze do profilu Użytkownika

Użytkownicy Serwisu mogą umieszczać na swoich profilach i profilach innych Użytkowników różnego rodzaju komentarze i informacje, korzystając z udostępnionego w tym celu w Serwisie formularza.

## Wymagania techniczne

### § 4

Korzystanie z usług Serwisu wymaga korzystania z przeglądarki internetowej MSIE 8.0, Firefox 3.6, Opera 11, Chrome 16 lub kompatybilnej, z włączoną opcją „cookies", obsługą JavaScript, oraz rozdzielczością ekranu przynajmniej 1280x800.

Użytkownik jest świadomy, że korzystanie z oprogramowania typu Adblock Plus lub Flashblock może spowodować nieprawidłowe funkcjonowanie Serwisu lub może całkowicie uniemożliwić korzystanie z niego.

## Rejestracja i konto Użytkownika

### § 5

Rejestracja, założenie oraz prowadzenie konta Użytkownika w Serwisie jest bezpłatne.

Rejestracja Użytkownika następuje poprzez poprawne wypełnienie i przesłanie Administratorowi formularza rejestracyjnego (http://zadane.pl/rejestracja).

Zabronione jest używanie nicków zawierających słowa „moderator" lub „admin", „administrator", chyba, że jest to konto moderatora bądź administratora serwisu.

Użytkownik ma obowiązek podać w formularzu prawdziwe dane. W przypadku stwierdzenia podania przez Użytkownika fałszywych danych Administratorowi przysługuje prawo odmowy jego rejestracji lub - w przypadku ustalenia, że dane są nieprawdziwe, po dokonaniu rejestracji – prawo zablokowania konta Użytkownika oraz jego wyrejestrowania z Serwisu. O fakcie oraz przyczynach odmowy rejestracji lub blokady konta Użytkownik będzie poinformowany przez Administratora drogą elektroniczną.

Użytkownik jest uprawniony i zobowiązany do aktualizacji swoich danych osobowych, o ile po dokonaniu rejestracji ulegną one zmianie. Zgłoszenie zmiany danych następuje poprzez wypełnienie i przesłanie Administratorowi formularza aktualizacyjnego po zalogowaniu się na konto (http://zadane.pl/users/change_data).

Możliwość korzystania z usług Serwisu może zostać uzależniona od potwierdzenia przez Użytkownika jego danych osobowych odpowiednim dokumentem (np. dowodem osobistym, odpisem lub zaświadczeniem z właściwego rejestru lub ewidencji, zaświadczeniem o numerze identyfikacyjnym REGON itp.) w sposób wskazany przez Organizatorów, w tym poprzez zobowiązanie Użytkownika do przesłania kserokopii dokumentu pocztą lub jego skanu drogą elektroniczną.

Przesłanie Administratorowi formularza rejestracyjnego traktuje się jako:

- zgodę Użytkownika na przetwarzanie jego danych osobowych w celu realizacji usług Serwisu,
- zaakceptowanie przez Użytkownika postanowień Regulaminu,
- zgodę Użytkownika na otrzymywanie materiałów reklamowych od Administratora;

Po dokonaniu rejestracji Użytkownik dokonuje aktywacji osobistego elektronicznego konta w Serwisie.

Użytkownik nie ma prawa udostępniania swojego konta osobom trzecim lub korzystania z kont innych Użytkowników.

Użytkownik może zostać wyrejestrowany z Serwisu:

- na swoje żądanie – przesyłając Administratorowi formularz wyrejestrowania konta (http://zadane.pl/users/confirm_account_delete) i postępując zgodnie z otrzymanymi wskazówkami;
- bez swojej zgody – w razie stwierdzenia naruszenia przez Użytkownika przepisów prawa lub postanowień Regulaminu, a także w razie zawieszenia, przebudowy funkcjonalności lub likwidacji Serwisu.

W przypadku stwierdzenia naruszenia przez Użytkownika przepisów prawa lub postanowień Regulaminu jego konto może zostać zablokowane, Użytkownik wyrejestrowany z Serwisu, a dostęp do umieszczonych przez niego w Serwisie Treści zablokowany lub Treści te mogą zostać na stałe usunięte z Serwisu. Zastosowanie wskazanych sankcji nie pozbawia Administratora możliwości skorzystania w stosunku do Użytkownika z innych przewidzianych prawem środków, ani odpowiedzialności Użytkownika z tytułu dokonanych przez siebie naruszeń praw osób trzecich.

Usunięcie konta Użytkownika w przypadkach przewidzianych w Regulaminie oznacza wyrejestrowanie Użytkownika z Serwisu.

Po dokonaniu rejestracji w Serwisie do każdego Użytkownika przypisany zostaje profil Użytkownika.

## Umieszczanie i przechowywanie Treści

### § 6

Zakazane jest umieszczanie przez Użytkowników i przechowywanie w Serwisie Treści – w tym pytań, odpowiedzi, rozwiązań, wypracowań, prac tematycznych, prywatnych wiadomości oraz wypowiedzi w ramach uczestnictwa w grupach dyskusyjnych oraz dyskusjach:

- mających bezprawny charakter, w szczególności naruszających cudze prawa własności intelektualnej, w tym prawa autorskie oraz cudze dobra osobiste,
- mających charakter reklamy, w tym w szczególności reklamy serwisów konkurencyjnych w stosunku do Serwisu,obraźliwych, naruszających dobre obyczaje, w tym wulgaryzmów,
- naruszających przepisy prawa bezwzględnie obowiązującego,
- naruszających dobry wizerunek Serwisu.

Umieszczenie w Serwisie Treści stanowiących przedmiot prawa autorskiego lub innego prawa własności intelektualnej traktowane jest jako oświadczenie Użytkownika, że:

- przysługują mu wyłączne prawa majątkowe - autorskie lub odpowiednie inne prawa własności intelektualnej - do jej utrwalenia, zwielokrotnienia oraz udostępnienia w taki sposób, aby każdy mógł mieć do niej dostęp w czasie i miejscu przez siebie wybranym;
- za pośrednictwem Serwisu nieodpłatne publicznie udostępnia umieszczoną w nim Treść w taki sposób, aby każdy mógł mieć do niej dostęp w czasie i miejscu przez siebie wybranym;
- udziela Organizatorowi nieodpłatnej zgody na utrzymanie umieszczonych przez siebie Treści na stronie internetowej Serwisu.

Użytkownik umieszczający w Serwisie Treść chronioną prawem autorskim lub innym prawem własności intelektualnej ponosi pełną odpowiedzialność karną oraz cywilną za ewentualne związane z tym naruszenia praw osób trzecich.

Umieszczenie w Serwisie Treści w rozumieniu niniejszego Regulaminu następuje z chwilą przesłania jej przez Użytkownika drogą elektroniczną Administratorowi przy użyciu formularza umieszczonego na stronie internetowej Serwisu.

Umieszczenie w Serwisie Treści następuje na czas nieoznaczony – z uwzględnieniem postanowień Regulaminu dotyczących skutków wypowiedzenia przez Użytkownika umowy o świadczenie usług Serwisu.

W uzasadnionych przypadkach, w szczególności w razie wątpliwości co do respektowania przez Użytkownika postanowień Regulaminu, Administratorowi Serwisu przysługuje prawo sporządzenia i zachowania kopii umieszczonych przez Użytkownika Treści przed ich usunięciem ze strony internetowej Serwisu.

Treści umieszczone przez Użytkownika mogą zostać usunięte z Serwisu w przypadkach przewidzianych postanowieniami Regulaminu oraz przepisami prawa.

## Korzystanie z Treści

### § 7

Użytkownikom przysługuje prawo korzystania z umieszczonych w Serwisie Treści jedynie na własne potrzeby, w celach nie mających charakteru komercyjnego. W przypadku, gdy Treść stanowi przedmiot prawa autorskiego lub pokrewnego, Użytkownik może z niej korzystać w ramach dozwolonego użytku przewidzianego przepisami ustawy o prawie autorskim i prawach pokrewnych.

Korzystanie z Treści na zasadach określonych w Regulaminie jest nieodpłatne.

Użytkownicy ponoszą pełną odpowiedzialność karną oraz cywilną za dokonane przez siebie naruszenia cudzych praw autorskich lub pokrewnych do Treści umieszczonych w Serwisie.

## Kontrola Treści. Moderacja

### § 8

Administrator ma prawo kontrolować – w miarę swoich możliwości – umieszczane przez Użytkowników Treści w celu wyeliminowania z Serwisu tych, które nie spełniają warunków określonych w Regulaminie.

W przypadku stwierdzenia, że umieszczona w Serwisie treść nie spełnia warunków określonych w Regulaminie lub w przypadku uzasadnionych wątpliwości w tym zakresie, Administratorowi przysługuje prawo usunięcia umieszczonej przez Użytkownika Treści z Serwisu.

Treści umieszczone w Serwisie oraz zachowania Użytkowników poddawane są tzw. moderacji. Moderacja oznacza ich weryfikację, która jest dokonywana z uwzględnieniem poniższych zasad.

Moderacja dokonywana jest na trzech następujących poziomach:

- moderacja ze strony Serwisu – dotycząca treści wypracowań i prac tematycznych, dokonywana przez osobę upoważnioną do tego przez Organizatora Serwisu - przed wyświetleniem moderowanych materiałów pozostałym Użytkownikom,
- moderacja społeczna – dotycząca wszystkich dostępnych Użytkownikom zasobów Serwisu, może być dokonywana przez każdego z Użytkowników Serwisu - po wyświetleniu moderowanych materiałów pozostałym Użytkownikom,
- moderacja grupowa - dotycząca wszystkich dostępnych Użytkownikom zasobów Serwisu, dokonywana przez Użytkowników wybranych przez Administratora - po wyświetleniu moderowanych materiałów pozostałym Użytkownikom.

Moderacja ze strony Serwisu odbywa się na zasadach określonych w postanowieniach Regulaminu dotyczących wypracowań oraz prac tematycznych.

Moderacja społeczna polega na możliwości zgłoszenia przez każdego Użytkownika faktu umieszczenia w Serwisie Treści mających charakter spamu lub błędnego udzielenia odpowiedzi na jego pytanie. Moderacja społeczna dokonywana jest z wykorzystaniem udostępnionych w tym celu w Serwisie instrumentów komunikacyjnych.

Moderacja grupowa polega na monitorowaniu umieszczonych z Serwisie Treści z uwzględnieniem następujących kompetencji moderatorów:

- prawa usunięcia kont Użytkownika w przypadku stwierdzenia, że ten sam Użytkownik wbrew postanowieniom Regulaminu zarejestrował się w Serwisie minimum dwukrotnie,
- prawa usunięcia Treści umieszczonych przez Użytkownika w Serwisie, które nie uwzględniają wymogów określonych w Regulaminie,
- prawa usunięcia konta Użytkownika w przypadku stwierdzenia naruszania przez niego przepisów prawa lub postanowień Regulaminu; skorzystanie z tego prawa może zostać poprzedzone pouczeniem i ostrzeżeniem Użytkownika, że w przypadku dalszego dokonywania ww. naruszeń zostanie wyrejestrowany z Serwisu;
- prawa zablokowania dostępności do Serwisu komputera, za pomocą którego Użytkownik tworzy konta, za pośrednictwem których nagminnie narusza Regulamin, uprzykrza pracę innym Użytkownikom, Administratorowi lub moderatorom;
- prawa wykonywania prac redakcyjnych dotyczących umieszczonych przez Użytkowników Treści w celu zapewnienia ich odpowiedniej prezentacji, w tym prawo ich kategoryzacji, zmiany tytułu, podziału na mniejsze części w przypadku złożoności Treści, poprawy oczywistych omyłek pisarskich itp.;

Administrator może przydzielać moderatorowi dodatkowe uprawnienia ukierunkowane na zapewnienie prawidłowego funkcjonowania Serwisu lub pozbawiać go określonych uprawnień, jeśli ich wykonywanie przez moderatora stanie się z jakichkolwiek przyczyn zbędne lub z innych przyczyn niezasadne.

## Polityka Prywatności

### § 12

Administrator gwarantuje ochronę udostępnionych przez Użytkowników danych osobowych. Przetwarzanie danych osobowych w ramach Serwisu odbywa się zgodnie z zasadami określonymi w ustawie o ochronie danych osobowych, ustawie o świadczeniu usług drogą elektroniczną oraz Regulaminie.

Przetwarzanie danych osobowych Użytkowników następuje wyłącznie w celu realizacji usług Serwisu oraz w celu dostarczania Użytkownikom materiałów stanowiących reklamę lub promocję Serwisu.

Dane osobowe zgromadzone w Serwisie mogą być także wykorzystywane w celu informowania Użytkowników o Serwisie i świadczonych przez niego usługach oraz udostępnione:

- odpowiednim organom państwowym na ich żądanie na podstawie odpowiednich przepisów prawa,
- podmiotom reprezentującym Organizatora w dochodzeniu roszczeń przysługujących mu z tytułu świadczenia usług Serwisu w stosunku do Użytkownika, którego dotyczą dane osobowe osób fizycznych oraz dane innych podmiotów korzystających z usług Serwisu,
- innym osobom i podmiotom – w przypadkach przewidzianych przez przepisy prawa.

Zakres przetwarzanych w Serwisie danych Użytkowników obejmuje następujące informacje: imiona i nazwiska, , adres email, adres pocztowy, płeć, datę urodzenia, numer telefonu, numer w systemie komunikacji Gadu-gadu, poziom nauki Użytkownika.

Podstawą prawną upoważniającą do prowadzenia zbioru danych osobowych jest zgoda Użytkowników, których dane dotyczą, oraz wskazane wyżej przepisy prawa.

Udostępnianie danych osobowych przez Użytkowników ma charakter dobrowolny, jednak – w odniesieniu do niektórych danych - konieczny do realizacji usług Serwisu.. Dane są udostępniane Administratorowi na etapie rejestracji Użytkownika w Serwisie oraz na etapie dokonywania korekty lub aktualizacji danych.

Administrator stosuje odpowiednie środki techniczne i organizacyjne w celu zapewnienia bezpieczeństwa danych osobowych udostępnionych przez Użytkowników, w szczególności w celu uniemożliwienia dostępu do nich osób trzecich, przetwarzania z naruszeniem przepisów prawa, zapobieżenia ich utracie, uszkodzeniu lub zniszczeniu.

Użytkownikom przysługuje prawo:

- dostępu do swoich danych osobowych udostępnionych w związku z korzystaniem z usług Serwisu, prawo dokonywania uzupełnienia, korekt oraz aktualizacji treści tychże danych; uprawnienia te Użytkownik realizuje w drodze uzupełnienia oraz przesłania drogą elektroniczną odpowiedniego formularza aktualizacyjnego,
- żądania czasowego lub stałego wstrzymania przetwarzania danych osobowych lub ich usunięcia, o ile okazałyby się one niekompletne, nieaktualne, nieprawdziwe lub zebrane z naruszeniem przepisów prawa,
- sprzeciwu wobec przetwarzania jego danych osobowych – w przypadkach przewidzianych przepisami prawa – oraz prawo żądania ich usunięcia, gdy staną się one zbędne do realizacji celu, dla którego zostały zebrane.

Pomimo zakończenia korzystania z usługi świadczonej w ramach Serwisu Administrator może przetwarzać dane osobowe Użytkownika, o ile są one dopuszczone do przetwarzania na podstawie przepisów prawa lub porozumienia lub niezbędne:

- do rozliczenia usługi i dochodzenia roszczeń z tego tytułu,
- do wyjaśnienia okoliczności niedozwolonego, tj. sprzecznego z regulaminem lub obowiązującymi przepisami korzystania z usługi,
- w celu dostarczania Użytkownikom materiałów stanowiących reklamę lub promocję Serwisu.

W związku z korzystaniem przez Użytkownika z usług Serwisu przetwarzane są także dane eksploatacyjne, w tym dotyczące numeru IP komputera Użytkownika, na którym zapisywane są pliki cookie, umożliwiające łatwiejsze korzystanie z Serwisu.

W ramach profilu Użytkownika, otrzymanego przez każdego Użytkownika po zarejestrowaniu się w Serwisie, pozostałym Użytkownikom udostępnione są następujące dane: imię, nazwisko, wiek, płeć, numer w komunikatorze Gadu-Gadu, data rejestracji Użytkownika w Serwisie, data ostatniego logowania Użytkownika w Serwisie, poziom nauki Użytkownika.

Na pytania Użytkownika dotyczące zasad przetwarzania w Serwisie danych osobowych, kierowane do Serwisu drogą e-mailową za pomocą formularza na stronie: http://zadane.pl/contact, Administrator odpowiada na podany w formularzu email w możliwie najszybszym terminie.

## Odpowiedzialność Administratora

### § 13

Administrator nie ponosi odpowiedzialności za:

- prawdziwość podanych przez Użytkowników danych osobowych,
- działania lub zaniechania Użytkowników naruszające przepisy prawa lub postanowienia Regulaminu oraz
- naruszenia przez Użytkowników cudzych praw w związku z korzystaniem z Serwisu – w szczególności gdy udostępniając zasoby systemu teleinformatycznego w celu przechowywania lub udostępniania przez Użytkowników Treści Administrator nie wie o bezprawnym charakterze tychże Treści lub związanej z nimi działalności, a w razie otrzymania urzędowego zawiadomienia lub uzyskania wiarygodnej wiadomości o bezprawnym charakterze Treści lub związanej z nimi działalności niezwłocznie uniemożliwi dostęp do wskazanych Treści.
- wypłacalność Użytkowników,
- zgodność umieszczonych przez Użytkowników Treści z zasadami wiedzy z danego przedmiotu szkolnego, którego Treści te dotyczą,
- działania lub zaniechania dostawców usług internetowych oraz awarie i zakłócenia w działaniu sieci
- internetowej, za pośrednictwem której Użytkownik korzysta z usług Serwisu,
- działania Użytkowników lub innych osób uniemożliwiające lub zakłócające korzystanie z usług Serwisu,
- wadliwe działanie Serwisu spowodowane siłą wyższą.

Niezależnie od powyższego Administrator w miarę możliwości dba o odpowiedni poziom merytoryczny Serwisu, w tym umieszczanych w nim Treści oraz reklam.

W razie stwierdzenia naruszenia przez któregokolwiek z Użytkowników przepisów prawa lub postanowień Regulaminu, Administratorowi przysługuje prawo zastosowania środków przewidzianych w Regulaminie, w tym blokady konta nieuczciwego Użytkownika i jego wyrejestrowania z Serwisu. Administrator oświadcza jednak, że niejednokrotnie nie ma możliwości weryfikacji legalności działania Użytkowników, w tym dokonania oceny, czy działanie to nie narusza cudzych praw. Za skutki naruszeń odpowiadają Użytkownicy, którzy naruszeń się dopuścili.

## Postępowanie reklamacyjne

### § 14

Użytkownikowi przysługuje prawo składania reklamacji dotyczących jakości świadczonych w ramach Serwisu usług.

Reklamacje składane są drogą elektroniczną na adres poczty elektronicznej kontakt@zadane.pl

Administrator rozpatruje reklamację Użytkownika w możliwie najkrótszym terminie, w miarę możliwości w terminie do 7 dni.

## Rozwiązywanie umów o świadczenie usług Serwisu

### § 15

Umowa o świadczenie usługi Serwisu zawartej pomiędzy Użytkownikiem a Serwisem może zostać w każdym czasie wypowiedziana przez Użytkownika ze skutkiem natychmiastowym.

Złożenie przez Użytkownika oświadczenia woli w celu rozwiązania umowy następuje w drodze e-maila przesłanego Administratorowi na adres email kontakt@zadane.pl

Organizatorowi Serwisu przysługuje prawo wypowiedzenia zawartej z Użytkownikiem umowy o świadczenie usług Serwisu:

- w przypadku niewykonania lub nienależytego wykonania tejże umowy przez Użytkownika – ze skutkiem natychmiastowym,
- w pozostałych przypadkach – z dwutygodniowym okresem wypowiedzenia.

Wypowiedzenie umowy następuje w drodze złożenia Użytkownikowi oświadczenia woli w formie elektronicznej.

Wygaśnięcie umowy zawartej pomiędzy Użytkownikiem a Serwisem skutkuje likwidacją konta Użytkownika, jego wyrejestrowaniem z Serwisu oraz usunięciem umieszczonych przez niego w Serwisie Treści , z tym zastrzeżeniem, że w przypadku gdy Treścią tą jest pytanie, może ono być nadal – bezterminowo - przechowywane w Serwisie, jeśli zostało w nim również umieszczona odpowiedź lub rozwiązania problemów zawartych zadania pytaniu.

Usunięcie z Serwisu danych osobowych Użytkownika odbywa się w takim przypadku z uwzględnieniem zasad Polityki Prywatności.

## Zmiany Regulaminu

### § 16

Regulamin może ulec zmianie, o czym Użytkownicy będą informowani poprzez wskazanie daty ostatniej zmiany Regulaminu na stronie internetowej Serwisu.

Użytkownik ma prawo odmowy akceptacji nowej wersji Regulaminu. Oświadczenie Użytkownika w tym zakresie może zostać złożone w formie e-maila przesłanego Administratorowi w ciągu 7 dni od daty zmiany Regulaminu.

Odmowa akceptacji nowej wersji Regulaminu skutkuje wygaśnięciem zawartej z Użytkownikiem umowy o świadczenie usług elektronicznych i w konsekwencji likwidacją konta Użytkownika oraz jego wyrejestrowaniem z Serwisu. Usunięcie z Serwisu danych osobowych Użytkownika odbywa się w takim przypadku z uwzględnieniem zasad Polityki Prywatności.